@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: monad-journal
 version: 0.7.1
-id: monad-journal-0.7.1-9e11141a847c41c0ccebac743a25d261
-key: monad_96UpxmtzM4nFzlgPkU77Cv
+id: monad-journal-0.7.1-30445f5e9b39786552a52a188cdfef1a
+key: monad_C0FiUZyGHCI0UY4jIyrc55
 license: BSD3
 maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
 homepage: http://github.com/phaazon/monad-journal
@@ -25,11 +25,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-journal-0.7.1
-hs-libraries: HSmonad-journal-0.7.1-96UpxmtzM4nFzlgPkU77Cv
+hs-libraries: HSmonad-journal-0.7.1-C0FiUZyGHCI0UY4jIyrc55
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    either-4.4.1-02b52c35841743771b37e0d5948e3cc8
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    either-4.4.1-21ae2d1687c4725fd9b94c0f754d4fd7
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
